@@ -22,7 +22,7 @@ from bitmaptools import draw_line, fill_region
 from ulab import numpy as np
 from vectorio import Polygon
 
-__version__ = "1.0.1"
+__version__ = "1.1.2"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
@@ -39,6 +39,9 @@ class Cartesian:
         rangex: Optional[list] = None,
         rangey: Optional[list] = None,
         line_color: Optional[int] = None,
+        line_style: Optional[str] = None,
+        ticksx: Union[np.array, list] = None,
+        ticksy: Union[np.array, list] = None,
         fill: bool = False,
         nudge: bool = True,
         logging: bool = False,
@@ -51,44 +54,61 @@ class Cartesian:
         :param list|None rangex: x range limits. Defaults to None
         :param list|None rangey: y range limits. Defaults to None
         :param int|None line_color: line color. Defaults to None
+        :param str|None line_style: line style. Defaults to None
+        :param np.array|list ticksx: X axis ticks values
+        :param np.array|list ticksy: Y axis ticks values
         :param bool fill: Show the filling. Defaults to `False`
         :param bool nudge: moves the graph a little for better displaying. Defaults to `True`
         :param bool logging: used to change the logic of the cartesian to work as a logger
 
         """
         self.points = []
+        self.ticksx = ticksx
+        self.ticksy = ticksy
 
         if line_color is not None:
             plot._plot_palette[plot._index_colorused] = line_color
 
+        if line_style is None:
+            self._line_type = "-"
+        else:
+            self._line_type = line_style
+
+        if self._line_type not in ["-", ".", "- -", "-.-"]:
+            raise ValueError("line_style must be a valid option")
+
+        if line_style is None:
+            self._line_type = "-"
+
         if nudge:
             nudge_factor = 1
         else:
             nudge_factor = 0
 
         if rangex is None:
-            xmin = np.min(x) - nudge_factor * (abs(np.max(x) - np.min(x)) / 10)
-            xmax = np.max(x) + nudge_factor * (abs(np.max(x) - np.min(x)) / 10)
+            self.xmin = np.min(x) - nudge_factor * (abs(np.max(x) - np.min(x)) / 10)
+            self.xmax = np.max(x) + nudge_factor * (abs(np.max(x) - np.min(x)) / 10)
+
         else:
-            xmin = min(rangex)
-            xmax = max(rangex)
+            self.xmin = min(rangex)
+            self.xmax = max(rangex)
 
         if rangey is None:
-            ymin = np.min(y) - nudge_factor * (abs(np.max(y) - np.min(y)) / 10)
-            ymax = np.max(y) + nudge_factor * (abs(np.max(y) - np.min(y)) / 10)
+            self.ymin = np.min(y) - nudge_factor * (abs(np.max(y) - np.min(y)) / 10)
+            self.ymax = np.max(y) + nudge_factor * (abs(np.max(y) - np.min(y)) / 10)
         else:
-            ymin = min(rangey)
-            ymax = max(rangey)
+            self.ymin = min(rangey)
+            self.ymax = max(rangey)
 
         x = np.array(x)
         y = np.array(y)
 
         xnorm = np.array(
-            plot.transform(xmin, xmax, plot._newxmin, plot._newxmax, x),
+            plot.transform(self.xmin, self.xmax, plot._newxmin, plot._newxmax, x),
             dtype=np.int16,
         )
         ynorm = np.array(
-            plot.transform(ymin, ymax, plot._newymin, plot._newymax, y),
+            plot.transform(self.ymin, self.ymax, plot._newymin, plot._newymax, y),
             dtype=np.int16,
         )
 
@@ -121,22 +141,17 @@ class Cartesian:
             for index, _ in enumerate(xnorm):
                 if index + 1 >= len(xnorm):
                     break
-                if y[index] >= ymax:
+                if y[index] >= self.ymax:
                     continue
-                draw_line(
-                    plot._plotbitmap,
-                    xnorm[index],
-                    ynorm[index],
-                    xnorm[index + 1],
-                    ynorm[index + 1],
-                    plot._index_colorused,
-                )
+
+                self._draw_plotline(plot, index, xnorm, ynorm)
+
         if plot._showticks:
             if plot._cartesianfirst:
                 if logging:
-                    x = np.linspace(xmin, xmax, 100)
-                    y = np.linspace(ymin, ymax, 100)
-                plot._draw_ticks(x, y)
+                    x = np.linspace(self.xmin, self.xmax, 100)
+                    y = np.linspace(self.ymin, self.ymax, 100)
+                plot._draw_ticks(x, y, self.ticksx, self.ticksy)
                 plot._cartesianfirst = False
                 plot._showticks = False
 
@@ -144,3 +159,39 @@ class Cartesian:
             plot._index_colorused = plot._index_colorused
         else:
             plot._index_colorused = plot._index_colorused + 1
+
+    def _draw_plotline(self, plot, index, xnorm, ynorm):
+        if self._line_type == "-":
+            self._plot_line(plot, index, xnorm, ynorm)
+        elif self._line_type == "-.-":
+            if index % 3 == 0:
+                self._plot_line(plot, index, xnorm, ynorm)
+            else:
+                plot._plotbitmap[xnorm[index], ynorm[index]] = plot._index_colorused
+        elif self._line_type == ".":
+            plot._plotbitmap[xnorm[index], ynorm[index]] = plot._index_colorused
+        elif self._line_type == "- -":
+            if index % 2 == 0:
+                self._plot_line(plot, index, xnorm, ynorm)
+
+    @staticmethod
+    def _plot_line(plot, index, xnorm, ynorm):
+        draw_line(
+            plot._plotbitmap,
+            xnorm[index],
+            ynorm[index],
+            xnorm[index + 1],
+            ynorm[index + 1],
+            plot._index_colorused,
+        )
+
+
+class LineStyle:
+    """
+    Line style class
+    """
+
+    SOLID = "-"
+    DASHED = "- -"
+    DASH_DOT = "-.-"
+    DOTTED = "."
