@@ -21,12 +21,8 @@ Implementation Notes
 
 """
 
-# pylint: disable=too-many-statements, unused-import, no-member
-# pylint: disable=unused-import, import-outside-toplevel, undefined-variable
-# pylint: disable=attribute-defined-outside-init
-
 try:
-    from typing import Union, Tuple
+    from typing import Union, Tuple, Optional
     from typing_extensions import Literal
 except ImportError:
     pass
@@ -37,7 +33,7 @@ from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 __repo__ = "https://github.com/jposada202020/CircuitPython_uplot.git"
 
 
@@ -82,13 +78,13 @@ class Plot(displayio.Group):
             height = 100
         if x + width > 481:
             print(
-                "Modify this settings. Some of the graphics will not shown int the screen"
+                "Modify this setting. Some of the graphics will not shown int the screen"
             )
             print("Defaulting to x=0")
             x = 0
         if y + height > 321:
             print(
-                "Modify this settings. Some of the graphics will not shown int the screen"
+                "Modify this setting. Some of the graphics will not shown int the screen"
             )
             print("Defaulting to y=0")
             y = 0
@@ -96,6 +92,7 @@ class Plot(displayio.Group):
         super().__init__(x=x, y=y, scale=scale)
 
         self._axesparams = "box"
+        self._decimal_points = None
 
         self._width = width
         self._height = height
@@ -165,12 +162,13 @@ class Plot(displayio.Group):
         """
         Setting up axs visibility
 
-        :param axstype: argument with the kind of axs you selected
+        :param str axstype: argument with the kind of axs you selected
 
         :return: None
 
         """
         self._axesparams = axstype
+        self._update_plot()
 
     def _drawbox(self) -> None:
         """
@@ -179,6 +177,7 @@ class Plot(displayio.Group):
         :return: None
 
         """
+        self._plotbitmap.fill(0)
 
         if self._axesparams == "cartesian":
             draw_box = [True, True, False, False]
@@ -231,7 +230,8 @@ class Plot(displayio.Group):
 
     def draw_circle(self, radius: int = 5, x: int = 100, y: int = 100) -> None:
         """
-        Draw a circle in the plot area
+        Draw a circle in the plot area. This function is kept here for
+        historical reasons. Please use :meth:`scatter` instead.
 
         :param int radius: circle radius
         :param int x: circles center x coordinate position in pixels, Defaults to 100.
@@ -270,24 +270,41 @@ class Plot(displayio.Group):
             / (oldrangemax - oldrangemin)
         ) + newrangemin
 
-    def _draw_ticks(self, x: int, y: int) -> None:
+    def _draw_ticks(self, x: int, y: int, ticksx=None, ticksy=None) -> None:
         """
         Draw ticks in the plot area
 
         :param int x: x coord
         :param int y: y coord
+        :param list[int] ticksx: x ticks data. Defaults to None
+        :param list[int] ticksy: y ticks data. Defaults to None
 
         :return:None
 
         """
 
-        ticks = np.array([10, 30, 50, 70, 90])
-        subticks = np.array([20, 40, 60, 80])
-        ticksxnorm = np.array(self.transform(0, 100, np.min(x), np.max(x), ticks))
-        ticksynorm = np.array(self.transform(0, 100, np.min(y), np.max(y), ticks))
+        ticks_dummy = np.array([10, 30, 50, 70, 90])
+        subticks_dummy = np.array([20, 40, 60, 80])
 
-        subticksxnorm = np.array(self.transform(0, 100, np.min(x), np.max(x), subticks))
-        subticksynorm = np.array(self.transform(0, 100, np.min(y), np.max(y), subticks))
+        if ticksx is None:
+            ticksxnorm = np.array(
+                self.transform(0, 100, np.min(x), np.max(x), ticks_dummy)
+            )
+            subticksxnorm = np.array(
+                self.transform(0, 100, np.min(x), np.max(x), subticks_dummy)
+            )
+        else:
+            ticksxnorm = np.array(ticksx)
+
+        if ticksy is None:
+            ticksynorm = np.array(
+                self.transform(0, 100, np.min(y), np.max(y), ticks_dummy)
+            )
+            subticksynorm = np.array(
+                self.transform(0, 100, np.min(y), np.max(y), subticks_dummy)
+            )
+        else:
+            ticksynorm = np.array(ticksy)
 
         ticksxrenorm = np.array(
             self.transform(
@@ -295,24 +312,27 @@ class Plot(displayio.Group):
             ),
             dtype=np.int16,
         )
+
         ticksyrenorm = np.array(
             self.transform(
                 np.min(y), np.max(y), self._newymin, self._newymax, ticksynorm
             ),
             dtype=np.int16,
         )
-        subticksxrenorm = np.array(
-            self.transform(
-                np.min(x), np.max(x), self._newxmin, self._newxmax, subticksxnorm
-            ),
-            dtype=np.int16,
-        )
-        subticksyrenorm = np.array(
-            self.transform(
-                np.min(y), np.max(y), self._newymin, self._newymax, subticksynorm
-            ),
-            dtype=np.int16,
-        )
+        if ticksx is None:
+            subticksxrenorm = np.array(
+                self.transform(
+                    np.min(x), np.max(x), self._newxmin, self._newxmax, subticksxnorm
+                ),
+                dtype=np.int16,
+            )
+        if ticksy is None:
+            subticksyrenorm = np.array(
+                self.transform(
+                    np.min(y), np.max(y), self._newymin, self._newymax, subticksynorm
+                ),
+                dtype=np.int16,
+            )
         for i, tick in enumerate(ticksxrenorm):
             draw_line(
                 self._plotbitmap,
@@ -326,7 +346,7 @@ class Plot(displayio.Group):
                 self.show_text(
                     "{:.{}f}".format(ticksxnorm[i], self._decimal_points),
                     tick,
-                    self._newymin,
+                    self._newymin + 5,
                     (0.5, 0.0),
                 )
         for i, tick in enumerate(ticksyrenorm):
@@ -341,28 +361,32 @@ class Plot(displayio.Group):
             if self._showtext:
                 self.show_text(
                     "{:.{}f}".format(ticksynorm[i], self._decimal_points),
-                    self._newxmin,
+                    self._newxmin - 5,
                     tick,
                     (1.0, 0.5),
                 )
-        for tick in subticksxrenorm:
-            draw_line(
-                self._plotbitmap,
-                tick,
-                self._newymin,
-                tick,
-                self._newymin - self._tickheightx // 2,
-                2,
-            )
-        for tick in subticksyrenorm:
-            draw_line(
-                self._plotbitmap,
-                self._newxmin,
-                tick,
-                self._newxmin + self._tickheighty // 2,
-                tick,
-                2,
-            )
+
+        if ticksx is None:
+            for tick in subticksxrenorm:
+                draw_line(
+                    self._plotbitmap,
+                    tick,
+                    self._newymin,
+                    tick,
+                    self._newymin - self._tickheightx // 2,
+                    2,
+                )
+
+        if ticksy is None:
+            for tick in subticksyrenorm:
+                draw_line(
+                    self._plotbitmap,
+                    self._newxmin,
+                    tick,
+                    self._newxmin + self._tickheighty // 2,
+                    tick,
+                    2,
+                )
 
         if self._tickgrid:
             self._draw_gridx(ticksxrenorm)
@@ -453,7 +477,7 @@ class Plot(displayio.Group):
                 )
                 start = start + self._grid_espace + self._grid_lenght
 
-    def update_plot(self) -> None:
+    def _update_plot(self) -> None:
         """
         Function to update graph
 
@@ -469,8 +493,9 @@ class Plot(displayio.Group):
         x: int,
         y: int,
         anchorpoint: Tuple = (0.5, 0.0),
-        text_color: int = 0xFFFFFF,
+        text_color: Optional[int] = None,
         free_text: bool = False,
+        font=None,
     ) -> None:
         """
 
@@ -479,27 +504,38 @@ class Plot(displayio.Group):
         :param int x: x coordinate
         :param int y: y coordinate
         :param Tuple anchorpoint: Display_text anchor point. Defaults to (0.5, 0.0)
-        :param int color: text color. Defaults to :const:`0xFFFFFF`
+        :param int color: text color. Defaults to None
         :param bool free_text: Select to show free text
+        :param font: font to be used. Defaults to None
         :return: None
         """
+        if font is None:
+            font = terminalio.FONT
         try:
             self.bitmap_label
         except AttributeError:
             from adafruit_display_text import bitmap_label
 
             self.bitmap_label = bitmap_label
+
+        if text_color is None:
+            text_color = self._plot_palette[2]
+
         if self._showtext or free_text:
             text_toplot = self.bitmap_label.Label(
-                terminalio.FONT, text=text, x=x, y=y, color=text_color
+                font, text=text, x=x, y=y, color=text_color
             )
             text_toplot.anchor_point = anchorpoint
             text_toplot.anchored_position = (x, y)
             self.append(text_toplot)
 
 
-# pylint: disable=missing-class-docstring, too-few-public-methods, invalid-name
+# pylint: disable=too-few-public-methods, invalid-name
 class color:
+    """
+    Class to define colors in HEX
+    """
+
     WHITE = 0xFFFFFF
     BLACK = 0x000000
     RED = 0xFF0000
@@ -510,3 +546,10 @@ class color:
     ORANGE = 0xFF9933
     TEAL = 0x158FAD
     GRAY = 0x808080
+    PINK = 0xFF40C0
+    LIGHT_GRAY = 0xAAAAAA
+    BROWN = 0xCA801D
+    DARK_GREEN = 0x008700
+    TURQUOISE = 0x00C0C0
+    DARK_BLUE = 0x0000AA
+    DARK_RED = 0x800000
