@@ -2,7 +2,6 @@
 #
 # SPDX-License-Identifier: MIT
 
-import time
 import board
 from circuitpython_uplot.plot import Plot
 from circuitpython_uplot.pie import Pie
@@ -21,7 +20,3 @@ Pie(plot, a)
 
 # Plotting and showing the plot
 display.show(plot)
-
-# Adding some wait time
-while True:
-    time.sleep(1)
