@@ -2,7 +2,6 @@
 #
 # SPDX-License-Identifier: MIT
 
-import time
 import board
 from circuitpython_uplot.plot import Plot
 
@@ -15,6 +14,3 @@ plot = Plot(0, 0, display.width, display.height)
 plot.draw_circle(radius=8, x=120, y=120)
 
 display.show(plot)
-
-while True:
-    time.sleep(1)
